aboutsummaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
authorAlessandro Astone <alessandro.astone@canonical.com>2025-10-06 15:43:52 +0200
committerMike Gabriel <mike.gabriel@das-netzwerkteam.de>2026-06-09 15:27:48 +0200
commit95ca9782d0ca105e14673b45acfeb8b66208b6c8 (patch)
tree2ffb878dbe757f0bbb07ddf1ee21957b11983568 /tests
parentdac009d0ffcdaf6caecf2b276e844d0946766c17 (diff)
downloadlibayatana-indicator-95ca9782d0ca105e14673b45acfeb8b66208b6c8.tar.gz
libayatana-indicator-95ca9782d0ca105e14673b45acfeb8b66208b6c8.tar.bz2
libayatana-indicator-95ca9782d0ca105e14673b45acfeb8b66208b6c8.zip
tests: Avoid more GDBusConnection leaks
The atk-bridge has started "leaking" a GDBusConnection since 2.57.0; disable it since it's not needed for the test. The GTK Wayland backend also "leaks" a GDBusConnection used to read settings in place of xsettings; force using the X11 backend.
Diffstat (limited to 'tests')
-rw-r--r--tests/test-indicator-ng.c4
1 files changed, 3 insertions, 1 deletions
diff --git a/tests/test-indicator-ng.c b/tests/test-indicator-ng.c
index 774b000..2b93236 100644
--- a/tests/test-indicator-ng.c
+++ b/tests/test-indicator-ng.c
@@ -174,11 +174,13 @@ test_menu (void)
int
main (int argc, char **argv)
{
/* gvfs, dconf, and appmenu-gtk leak GDbusConnections, which confuses
* g_test_dbus_down. Make sure we're not using any of those.
*/
g_setenv ("GIO_USE_VFS", "local", TRUE);
g_setenv ("GSETTINGS_BACKEND", "memory", TRUE);
+ g_setenv ("NO_AT_BRIDGE", "1", TRUE);
+ g_setenv ("GDK_BACKEND", "x11", TRUE);
g_unsetenv ("UBUNTU_MENUPROXY");
g_test_init (&argc, &argv, NULL);
@@ -174,11 +174,13 @@ test_menu (void)
main (int argc, char **argv)
{
- /* gvfs, dconf, and appmenu-gtk leak GDbusConnections, which confuses
+ /* gvfs, dconf, appmenu-gtk, atk-bridge and gdk-wayland leak GDbusConnections, which confuses
* g_test_dbus_down. Make sure we're not using any of those.
*/